@@ -4,16 +4,11 @@ import os
 from pathlib import Path
 from typing import Optional
 
-from rich.console import Console
-
-from pls import globals
 from pls.enums.node_type import NodeType
+from pls.globals import args, console
 from pls.models.node import Node
 
 
-console = Console()
-
-
 def sort_key(node: Node) -> tuple:
     """
     Map a ``Node`` instance to a string that represents it. This string is used
@@ -23,9 +18,9 @@ def sort_key(node: Node) -> tuple:
     :return: the value to use as the sort key for the node
     """
 
-    key = node.sort_keys[globals.state.sort.rstrip("-")]
-    is_reversed = globals.state.sort.endswith("-")
-    if not globals.state.no_dirs_first:
+    key = node.sort_keys[args.args.sort.rstrip("-")]
+    is_reversed = args.args.sort.endswith("-")
+    if args.args.dirs_first:
         if is_reversed:
             type_key = 1 if node.node_type == NodeType.DIR else 0
         else:
@@ -42,9 +37,9 @@ def passes_filters(node: Node) -> bool:
     :return: ``True`` if the node passes the filters, ``False`` otherwise
     """
 
-    if globals.state.exclude and globals.state.exclude.match(node.name) is not None:
+    if args.args.exclude and args.args.exclude.match(node.name) is not None:
         return False
-    if globals.state.only and globals.state.only.match(node.name) is None:
+    if args.args.only and args.args.only.match(node.name) is None:
         return False
     return True
 
@@ -58,13 +53,13 @@ def parse_node(node_name: str) -> Optional[Node]:
     :return: a ``Node`` instance
     """
 
-    node_path: Path = globals.state.directory.joinpath(node_name)
+    node_path: Path = args.args.directory.joinpath(node_name)
 
     if node_path.is_dir():
-        if globals.state.no_dirs:
+        if not args.args.dirs:
             return None
     else:  # is some kind of file
-        if globals.state.no_files:
+        if not args.args.files:
             return None
 
     return Node(name=node_name, path=node_path)
@@ -77,14 +72,14 @@ def read_input() -> tuple[dict[str, Node], list[Node]]:
     :return: the list of directories and files inside the given directory
     """
 
-    all_nodes = os.listdir(globals.state.directory)
+    all_nodes = os.listdir(args.args.directory)
 
     node_map = {}
     node_list = []
 
     if not all_nodes:
-        console.print(
-            f"There are no files or folders in [bold]{globals.state.directory}[/bold].",
+        console.console.print(
+            f"There are no files or folders in [repr.path]{args.args.directory}[/].",
             highlight=False,
         )
     else:
@@ -94,6 +89,6 @@ def read_input() -> tuple[dict[str, Node], list[Node]]:
             if (parsed_node := parse_node(node)) and passes_filters(parsed_node)
         }
         node_list = list(node_map.values())
-        node_list.sort(key=sort_key, reverse=globals.state.sort.endswith("-"))
+        node_list.sort(key=sort_key, reverse=args.args.sort.endswith("-"))
 
     return node_map, node_list
