@@ -1,13 +1,17 @@
 from __future__ import annotations
 
 import datetime
+import logging
 import os
 from itertools import cycle
 from stat import S_ISDIR
 from typing import Literal, Optional
 
-from pls import globals
 from pls.enums.unit_system import UnitSystem, get_base_and_pad_and_units
+from pls.globals import args, state
+
+
+logger = logging.getLogger(__name__)
 
 
 def _get_format_pair(rules: list[str]) -> tuple[str, str]:
@@ -105,7 +109,7 @@ def get_formatted_user(stat: os.stat_result) -> Optional[str]:
             pw_name = str(uid)
             format_rules.append("red")
 
-        if uid != globals.state.uid:
+        if uid != state.state.uid:
             format_rules.append("dim")
 
         left, right = _get_format_pair(format_rules)
@@ -135,7 +139,7 @@ def get_formatted_group(stat: os.stat_result) -> Optional[str]:
             gr_name = str(gid)
             format_rules.append("red")
 
-        if gid not in globals.state.gids:
+        if gid not in state.state.gids:
             format_rules.append("dim")
 
         left, right = _get_format_pair(format_rules)
@@ -150,7 +154,6 @@ def get_formatted_size(stat: os.stat_result) -> str:
     a compound unit of a byte. Uses ``st_size`` from the stat results.
 
     :param stat: the stat results of the node
-    :param is_dir: whether the node is a directory
     :return: the size of the node as a human-readable value
     """
 
@@ -159,10 +162,13 @@ def get_formatted_size(stat: os.stat_result) -> str:
     if S_ISDIR(stat.st_mode):
         return "[dim]-[/dim]"
 
-    if globals.state.units == UnitSystem.NONE:
+    if args.args.units == UnitSystem.NONE:
         return f"{st_size}[dim]B[/]"
 
-    base, pad, units = get_base_and_pad_and_units(globals.state.units)
+    base, pad, units = get_base_and_pad_and_units(args.args.units)
+    logger.debug(f"Base: {base}")
+    logger.debug(f"Pad: {pad}")
+    logger.debug(f"Units: {units}")
     for index, unit in reversed(list(enumerate(units))):
         order_of_magnitude = base ** index
         if st_size >= order_of_magnitude:
@@ -189,5 +195,5 @@ def get_formatted_time(
     st_time = getattr(stat, attr_name)
 
     dt = datetime.datetime.fromtimestamp(st_time)
-    fmt = globals.state.time_fmt
+    fmt = args.args.time_fmt
     return dt.strftime(fmt)
